@@ -105,7 +105,7 @@ gbmidwpred <- function (longlat, trainx, trainy, longlatpredx, predx,
   bag.fraction = 0.5,
   train.fraction = 1.0,
   n.minobsinnode = 10,
-  cv.fold = 10, # becuase of the way used to resample data, we can not do leave-one-out cv.
+  cv.fold = 10, # this is required for `gbm.perf`
   weights = rep(1, nrow(trainx)),   # by default set equal
   keep.data = FALSE,
   verbose = TRUE,
